VibrationUsage enum

Semantic category for the vibration request.

Maps to Android VibrationAttributes / AudioAttributes where supported.

Inheritance
Available extensions

Values

touch → const VibrationUsage

Touch feedback, e.g. keypresses, button taps.

notification → const VibrationUsage

Notification feedback, e.g. incoming message alerts.

ringtone → const VibrationUsage

Ringtone vibration for incoming phone calls.

alarm → const VibrationUsage

Alarm vibration.

media → const VibrationUsage

Vibration associated with media playback.

hardwareFeedback → const VibrationUsage

Hardware button or accessory feedback.

communicationRequest → const VibrationUsage

Communication requests such as video call invitations.

physicalEmulation → const VibrationUsage

Physical emulation, e.g. game controller vibrations.

unknown → const VibrationUsage

Unknown or default usage.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<VibrationUsage>
A constant List of the values in this enum, in order of their declaration.