MethodChannelFlutterVibrationManager class

An implementation of FlutterVibrationManagerPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → Future<VibrationResult>
Cancels any ongoing vibration.
override
capabilities() → Future<VibrationCapabilities>
Returns detailed capabilities of the device's vibration system.
override
haptic(HapticType type) → Future<VibrationResult>
Triggers haptic feedback.
override
hasAmplitudeControl() → Future<bool>
Checks if amplitude control is supported on this device.
override
hasVibrator() → Future<bool>
Checks if the device has a physical vibrator.
override
isSupported() → Future<bool>
Checks if vibration is supported on this platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notification(NotificationType type) → Future<VibrationResult>
Triggers notification feedback.
override
toString() → String
A string representation of this object.
inherited
vibrate({required Duration duration, int? amplitude, required VibrationUsage usage}) → Future<VibrationResult>
Triggers a simple vibration with optional amplitude and usage.
override
waveform({required List<Duration> pattern, List<int>? amplitudes, required int repeat, required VibrationUsage usage}) → Future<VibrationResult>
Triggers a pattern/waveform vibration with optional amplitudes and repeat.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited