VibrationCapabilities class
Capabilities of the vibrator hardware on the current device.
Constructors
- VibrationCapabilities({required bool hasVibrator, required bool supportsAmplitude, required bool supportsHaptics, required bool supportsWaveform})
-
Creates a VibrationCapabilities object.
const
- VibrationCapabilities.fromMap(Map map)
-
Factory constructor to parse map received from native platform.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasVibrator → bool
-
Whether the device has a physical vibrator motor.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsAmplitude → bool
-
Whether the device supports variable amplitude control.
final
- supportsHaptics → bool
-
Whether the device supports tactile haptic feedback (e.g. UIImpactFeedbackGenerator / Android predefines).
final
- supportsWaveform → bool
-
Whether the device supports custom vibration pattern waveforms.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts these capabilities into a map representation.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override